@@ -1,6 +1,6 @@
 # system modules
 
 # internal modules
-import thunar_plugins.menus.image
+import thunar_plugins.menus.link
 
 # external modules
